==> core_models-0.1.0.gem: app/controllers/core_models/base/payment_methods_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::PaymentMethodsController < CoreModelsController
    # GET /base/payment_methods
    # GET /base/payment_methods.json
    def index
      @base_payment_methods = Base::PaymentMethod.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_payment_methods }
      end
    end

    # GET /base/payment_methods/1
    # GET /base/payment_methods/1.json
    def show
      @base_payment_method = Base::PaymentMethod.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_payment_method }
      end
    end

    # GET /base/payment_methods/new
    # GET /base/payment_methods/new.json
    def new
      @base_payment_method = Base::PaymentMethod.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_payment_method }
      end
    end

    # GET /base/payment_methods/1/edit
    def edit
      @base_payment_method = Base::PaymentMethod.find(params[:id])
    end

    # POST /base/payment_methods
    # POST /base/payment_methods.json
    def create
      @base_payment_method = Base::PaymentMethod.new(params[:base_payment_method])

      respond_to do |format|
        if @base_payment_method.save
          format.html { redirect_to @base_payment_method, :notice => 'Payment method was successfully created.' }
          format.json { render :json => @base_payment_method, :status => :created, :location => @base_payment_method }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_payment_method.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/payment_methods/1
    # PUT /base/payment_methods/1.json
    def update
      @base_payment_method = Base::PaymentMethod.find(params[:id])

      respond_to do |format|
        if @base_payment_method.update_attributes(params[:base_payment_method])
          format.html { redirect_to @base_payment_method, :notice => 'Payment method was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_payment_method.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/payment_methods/1
    # DELETE /base/payment_methods/1.json
    def destroy
      @base_payment_method = Base::PaymentMethod.find(params[:id])
      @base_payment_method.destroy

      respond_to do |format|
        format.html { redirect_to base_payment_methods_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/base/payment_methods_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::PaymentMethodsController < CoreModelsController
    # GET /base/payment_methods
    # GET /base/payment_methods.json
    def index
      @base_payment_methods = Base::PaymentMethod.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_payment_methods }
      end
    end

    # GET /base/payment_methods/1
    # GET /base/payment_methods/1.json
    def show
      @base_payment_method = Base::PaymentMethod.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_payment_method }
      end
    end

    # GET /base/payment_methods/new
    # GET /base/payment_methods/new.json
    def new
      @base_payment_method = Base::PaymentMethod.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_payment_method }
      end
    end

    # GET /base/payment_methods/1/edit
    def edit
      @base_payment_method = Base::PaymentMethod.find(params[:id])
    end

    # POST /base/payment_methods
    # POST /base/payment_methods.json
    def create
      @base_payment_method = Base::PaymentMethod.new(params[:base_payment_method])

      respond_to do |format|
        if @base_payment_method.save
          format.html { redirect_to @base_payment_method, :notice => 'Payment method was successfully created.' }
          format.json { render :json => @base_payment_method, :status => :created, :location => @base_payment_method }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_payment_method.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/payment_methods/1
    # PUT /base/payment_methods/1.json
    def update
      @base_payment_method = Base::PaymentMethod.find(params[:id])

      respond_to do |format|
        if @base_payment_method.update(params[:base_payment_method])
          format.html { redirect_to @base_payment_method, :notice => 'Payment method was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_payment_method.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/payment_methods/1
    # DELETE /base/payment_methods/1.json
    def destroy
      @base_payment_method = Base::PaymentMethod.find(params[:id])
      @base_payment_method.destroy

      respond_to do |format|
        format.html { redirect_to base_payment_methods_url }
        format.json { head :no_content }
      end
    end
  end
end
